package HT.fx;

import java.util.List;

/**
 * @author joonatan, thmustap
 * @version 7.3.2024
 *
 */
public class Karkelot {
    private final Pelaajat pelaajat = new Pelaajat();
    private final Ottelut ottelut = new Ottelut();
    
    /**
     * Palautaa pelaajien määrän
     * @return pelaajatmäärä
     */
    public int getPelaajia() {
        return pelaajat.getLkm();
    }
    
    /**
     * Poistaa pelaajat aj ottelut tietyllä luvulla
     * @param nro , kuka poistetaan
     * @return montako poiistettiin
     */
    public int poista(@SuppressWarnings("unused") int nro) {
        return 0;
    }
    
    /**
     * lisää pelaajan
     * @param pelaaja pelaaja
     * @throws SailoException virhe
     */
    public void lisaa(Pelaaja pelaaja) throws SailoException {
        pelaajat.lisaa(pelaaja);
    }
    
    /**
     * Listään uusi harrastus kerhoon
     * @param ott lisättävä harrastus 
     */
    public void lisaa(Ottelu ott) {
        ottelut.lisaa(ott);
    }

    
    /**
     * Palauttaa i:n pelaajan 
     * @param i monesko pelaaja 
     * @return viite i:teen jäseneen
     * @throws IndexOutOfBoundsException jos i väärin
     */
    public Pelaaja annaPelaaja(int i) throws IndexOutOfBoundsException {
        return pelaajat.anna(i);
    }
    
    /**
     * @param pelaaja pelaaja kenelt' annetaan
     * @return palauttaa Ottelut
     */
    public List<Ottelu> annaOttelut(Pelaaja pelaaja) {
        return ottelut.annaOttelut(pelaaja.getTunnusNro());
    }
    
    /**
     * Hakee i:nnen ottelun ottelut oliolta
     * @param i monesko ottelu haetaan
     * @return ottelun
     */
    public Ottelu noudaOttelu(int i) {
        return ottelut.haeOttelu(i);
    }
    
    /**
     * Hakee kaikki ottelut
     * @return ottelut
     */
    public List<Ottelu> noudaOttelut() {
        return ottelut.haeOttelut();
    }
    
    public void paivitaRankingit() {
        int n = 1;
        while(n<getPelaajia()) {
            annaPelaaja(n).setRating(1000);
            n++;
        }
        
        for(Ottelu ottelu : ottelut) {
            int v1 = ottelu.getVoittajaNro1();
            int v2 = ottelu.getVoittajaNro2();
            annaPelaaja(v1).setRating(annaPelaaja(v1).getRating()+10);
            annaPelaaja(v2).setRating(annaPelaaja(v2).getRating()+10);
            
            int numerot[] = ottelu.getPelaajaNrot();
            int i = 0;
            while(i<4) {
                if(numerot[i] != v1 && numerot[i] != v2) {
                    annaPelaaja(numerot[i]).setRating(annaPelaaja(numerot[i]).getRating()-10);
                }
                i++;
            }
        }
            
    }
    
    
    /**
     * Lukee  tiedot tiedostosta
     * @param nimi joka luetaan
     * @param ekavaitoka kumpi luetaan
     * @throws SailoException virhe
     */
    public void lueTiedostosta(String nimi, int ekavaitoka) throws SailoException {
        
        
        if (ekavaitoka == 1) pelaajat.lueTiedostosta(nimi);
        if (ekavaitoka == 2) ottelut.lueTiedostosta(nimi);
    }
 
    
    /**
     * Tallentaa tiedot tiedostoon
     * @throws SailoException virhe
     */
    public void talleta() throws SailoException {
        pelaajat.talleta();
        ottelut.talleta();
    }
    
    /**
     * Testiohjelma kerhosta
     * @param args ei käytössä
     */
    public static void main(String args[]) {
        Karkelot karkelo = new Karkelot();

        try {
            // kerho.lueTiedostosta("kelmit");

            Pelaaja aku1 = new Pelaaja(), aku2 = new Pelaaja();
            aku1.rekisteroi();
            aku1.luoTesti();
            aku2.rekisteroi();
            aku2.luoTesti();

            karkelo.lisaa(aku1);
            karkelo.lisaa(aku2);

            System.out.println("============= Kerhon testi =================");

            for (int i = 0; i < karkelo.getPelaajia(); i++) {
                Pelaaja pelaaja = karkelo.annaPelaaja(i);
                System.out.println("Pelaaja paikassa: " + i);
                pelaaja.tulosta(System.out);
            }

        } catch (SailoException ex) {
            System.out.println(ex.getMessage());
        }
    }
}
